@@ -437,7 +437,7 @@ getnismaster (pam_handle_t *pamh, int flags)
   return master;
 }
 
-#if defined(HAVE_CRYPT_GENSALT_RN)
+#if defined(HAVE_XCRYPT_GENSALT_R)
 static int
 read_loop (int fd, char *buffer, int count)
 {
@@ -470,7 +470,7 @@ static char *
 make_crypt_salt (const char *crypt_prefix, int crypt_rounds,
 		 pam_handle_t *pamh, int flags)
 {
-#if defined(HAVE_CRYPT_GENSALT_RN)
+#if defined(HAVE_XCRYPT_GENSALT_R)
 #define CRYPT_GENSALT_OUTPUT_SIZE (7 + 22 + 1)
   int fd;
   char entropy[16];
@@ -497,7 +497,7 @@ make_crypt_salt (const char *crypt_prefix, int crypt_rounds,
 
   close (fd);
 
-  retval = crypt_gensalt_rn (crypt_prefix, crypt_rounds, entropy,
+  retval = xcrypt_gensalt_r (crypt_prefix, crypt_rounds, entropy,
 			     sizeof (entropy), output, sizeof(output));
 
   memset (entropy, 0, sizeof (entropy));
@@ -584,7 +584,7 @@ __do_setpass (pam_handle_t *pamh, int flags, user_t *data,
       else if (strcasecmp (crypt_str, "bf") == 0 ||
 	       strcasecmp (crypt_str, "blowfish") == 0)
 	{
-#if defined(HAVE_CRYPT_GENSALT_RN)
+#if defined(HAVE_XCRYPT_GENSALT_R)
 	  const char *round;
 	  char *cp;
 
@@ -667,7 +667,7 @@ __do_setpass (pam_handle_t *pamh, int flags, user_t *data,
 #endif
       break;
     case BLOWFISH:
-#if defined(HAVE_CRYPT_GENSALT_RN)
+#if defined(HAVE_XCRYPT_GENSALT_R)
       salt = make_crypt_salt ("$2a$", options->crypt_rounds, pamh, flags);
       if (salt != NULL)
 	newpassword = crypt_r (data->newpassword, salt, output);
@@ -686,7 +686,7 @@ __do_setpass (pam_handle_t *pamh, int flags, user_t *data,
       break;
     default:
       __write_message (pamh, flags, PAM_ERROR_MSG,
-		       "crypt_t: Don't know %d", options->use_crypt);
+		       "crypt_r: Don't know %d", options->use_crypt);
       return PAM_AUTHTOK_ERR;
     }
   if (newpassword == NULL)
